Added RPM install detail
[privoxy.git] / project.h
index 859707f..da8548e 100644 (file)
--- a/project.h
+++ b/project.h
@@ -1,6 +1,6 @@
 #ifndef PROJECT_H_INCLUDED
 #define PROJECT_H_INCLUDED
-#define PROJECT_H_VERSION "$Id: project.h,v 1.55 2002/03/12 01:42:50 oes Exp $"
+#define PROJECT_H_VERSION "$Id: project.h,v 1.65 2002/04/04 00:36:36 gliptak Exp $"
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/project.h,v $
@@ -10,7 +10,7 @@
  *                (though it does declare some macros).
  *
  * Copyright   :  Written by and Copyright (C) 2001 the SourceForge
- *                IJBSWA team.  http://ijbswa.sourceforge.net
+ *                Privoxy team. http://www.privoxy.org/
  *
  *                Based on the Internet Junkbuster originally written
  *                by and Copyright (C) 1997 Anonymous Coders and
  *
  * Revisions   :
  *    $Log: project.h,v $
+ *    Revision 1.65  2002/04/04 00:36:36  gliptak
+ *    always use pcre for matching
+ *
+ *    Revision 1.64  2002/04/03 22:28:03  gliptak
+ *    Removed references to gnu_regex
+ *
+ *    Revision 1.63  2002/03/31 17:19:00  jongfoster
+ *    Win32 only: Enabling STRICT to fix a VC++ compile warning.
+ *
+ *    Revision 1.62  2002/03/26 22:48:49  swa
+ *    new homepage url
+ *
+ *    Revision 1.61  2002/03/26 22:29:55  swa
+ *    we have a new homepage!
+ *
+ *    Revision 1.60  2002/03/24 15:52:17  jongfoster
+ *    Changing CGI URL prefixes for new name
+ *
+ *    Revision 1.59  2002/03/24 15:23:33  jongfoster
+ *    Name changes
+ *
+ *    Revision 1.58  2002/03/24 13:25:43  swa
+ *    name change related issues
+ *
+ *    Revision 1.57  2002/03/16 20:28:34  oes
+ *    Added descriptions to the filters so users will know what they select in the cgi editor
+ *
+ *    Revision 1.56  2002/03/13 20:27:30  oes
+ *    Fixing bug with CT_TABOO
+ *
  *    Revision 1.55  2002/03/12 01:42:50  oes
  *    Introduced modular filters
  *
  * and are included anyway.
  */
 
-#if defined(REGEX_PCRE) || defined (REGEX_GNU)
-# define REGEX
-#endif /* defined(REGEX_PCRE) || defined (REGEX_GNU) */
-
 #ifdef STATIC_PCRE
 #  include "pcre.h"
 #else
 #  include <pcrs.h>
 #endif
 
-#if defined(REGEX_PCRE)
-#  ifdef STATIC_PCRE
-#    include "pcreposix.h"
-#  else
-#    include <pcreposix.h>
-#  endif
-#endif /* defined(REGEX_PCRE) */
-
-#if defined(REGEX_GNU)
-#  include "gnu_regex.h"
+#ifdef STATIC_PCRE
+#  include "pcreposix.h"
+#else
+#  include <pcreposix.h>
 #endif
 
 #ifdef AMIGA
  * I don't want to have to #include all this just for the declaration
  * of SOCKET.  However, it looks like we have to...
  */
+#ifndef STRICT
+#define STRICT
+#endif
 #include <windows.h>
 #endif
 
@@ -609,15 +632,9 @@ struct url_spec
    char *path;         /* The path prefix (if not using regex), or source   */
                        /* for the regex.                                    */
    int   pathlen;      /* ==strlen(path).  Needed for prefix matching.      */
-#ifdef REGEX
    regex_t *preg;      /* Regex for matching path part                      */
-#endif
 };
-#ifdef REGEX
 #define URL_SPEC_INITIALIZER { NULL, NULL, NULL, 0, 0, 0, NULL, 0, NULL }
-#else /* ifndef REGEX */
-#define URL_SPEC_INITIALIZER { NULL, NULL, NULL, 0, 0, 0, NULL, 0 }
-#endif /* ndef REGEX */
 
 /* Constants for host part matching in URLs */
 #define ANCHOR_LEFT  1
@@ -753,7 +770,7 @@ struct url_actions
 #define CSP_FLAG_TOGGLED_ON 0x20 /* Set if we are toggled on (FEATURE_TOGGLE) */
 
 /*
* The state of a JunkBuster processing thread.
  */
 struct client_state
 {
@@ -852,7 +869,7 @@ struct cgi_dispatcher
 
 
 /*
* A data file used by JunkBuster.  Kept in a linked list.
  */
 struct file_list
 {
@@ -932,7 +949,8 @@ struct forward_spec
  */
 struct re_filterfile_spec
 {
-   char *filtername;                /* Name from FILTER: statement in re_filterfile (or "default") */
+   char *name;                      /* Name from FILTER: statement in re_filterfile */
+   char *description;               /* Description from FILTER: statement in re_filterfile */
    struct list patterns[1];         /* The patterns from the re_filterfile */
    pcrs_job *joblist;               /* The resulting compiled pcrs_jobs */
    struct re_filterfile_spec *next; /* The pointer for chaining */
@@ -978,7 +996,7 @@ struct configuration_spec
    int debug;
    int multi_threaded;
 
-   /* Features that can be enabled/disabled throuigh the config file */
+   /* Features that can be enabled/disabled through the config file */
    unsigned feature_flags;
 
    const char *logfile;
@@ -1040,7 +1058,7 @@ struct configuration_spec
 #define SZ(X)  (sizeof(X) / sizeof(*X))
 
 #ifdef FEATURE_FORCE_LOAD
-#define FORCE_PREFIX "/IJB-FORCE-LOAD"
+#define FORCE_PREFIX "/PRIVOXY-FORCE"
 #endif /* def FEATURE_FORCE_LOAD */
 
 #ifdef FEATURE_NO_GIFS
@@ -1051,7 +1069,7 @@ struct configuration_spec
 
 
 /* Hardwired URLs */
-#define HOME_PAGE_URL       "http://ijbswa.sourceforge.net"
+#define HOME_PAGE_URL       "http://www.privoxy.org"
 #define REDIRECT_URL        HOME_PAGE_URL "/redirect.php?v=" VERSION "&to="
 
 /*
@@ -1063,9 +1081,9 @@ struct configuration_spec
  * 2) CGI_SITE_2_PATH must not end with /, one will be added automatically.
  * 3) CGI_SITE_2_PATH must start with /, unless it is the empty string.
  */
-#define CGI_SITE_1_HOST "i.j.b"
-#define CGI_SITE_2_HOST "ijbswa.sourceforge.net"
-#define CGI_SITE_2_PATH "/config"
+#define CGI_SITE_1_HOST "p.p"
+#define CGI_SITE_2_HOST "config.privoxy.org"
+#define CGI_SITE_2_PATH ""
 
 /*
  * The prefix for CGI pages.  Written out in generated HTML.
@@ -1077,7 +1095,7 @@ struct configuration_spec
 /* HTTP snipplets */
 static const char CSUCCEED[] =
    "HTTP/1.0 200 Connection established\n"
-   "Proxy-Agent: IJ/" VERSION "\r\n\r\n";
+   "Proxy-Agent: Privoxy/" VERSION "\r\n\r\n";
 
 static const char CHEADER[] =
    "HTTP/1.0 400 Invalid header received from browser\r\n\r\n";
@@ -753,7 +770,7 @@ struct url_actions
 
 /*
- * The state of a JunkBuster processing thread.
+ * The state of a Privoxy processing thread.
  */
 struct client_state
@@ -852,7 +869,7 @@ struct cgi_dispatcher
 
 /*
- * A data file used by JunkBuster.  Kept in a linked list.
+ * A data file used by Privoxy.  Kept in a linked list.
  */
 struct file_list